@@ -25,5 +25,5 @@ class UserSchema(Schema):
     id = fields.Integer()
     name = fields.String()
     email = fields.String()
-    password = fields.String()
+    password = fields.String(load_only=True)
     active = fields.Integer()
